pub struct SpecialSubject {
pub id: Uuid,
pub key: String,
pub name: String,
pub parent: Option<Subject>,
}Fields
id: Uuidkey: Stringname: Stringparent: Option<Subject>Trait Implementations
Sourceimpl Clone for SpecialSubject
impl Clone for SpecialSubject
Sourcefn clone(&self) -> SpecialSubject
fn clone(&self) -> SpecialSubject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpecialSubject
impl Debug for SpecialSubject
Sourceimpl<'de> Deserialize<'de> for SpecialSubject
impl<'de> Deserialize<'de> for SpecialSubject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> FromSql<'a> for SpecialSubject
impl<'a> FromSql<'a> for SpecialSubject
Sourcefn from_sql(
_type: &Type,
buf: &'a [u8],
) -> Result<SpecialSubject, Box<dyn Error + Sync + Send>>
fn from_sql( _type: &Type, buf: &'a [u8], ) -> Result<SpecialSubject, Box<dyn Error + Sync + Send>>
Creates a new value of this type from a buffer of data of the specified
Postgres
Type in its binary format. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be created from the specified
Postgres
Type.Sourceimpl PartialEq for SpecialSubject
impl PartialEq for SpecialSubject
Sourceimpl Serialize for SpecialSubject
impl Serialize for SpecialSubject
Sourceimpl ToSql for SpecialSubject
impl ToSql for SpecialSubject
Sourcefn to_sql(
&self,
_type: &Type,
buf: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql( &self, _type: &Type, buf: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
Converts the value of
self into the binary format of the specified
Postgres Type, appending it to out. Read moreSourcefn accepts(type_: &Type) -> bool
fn accepts(type_: &Type) -> bool
Determines if a value of this type can be converted to the specified
Postgres
Type.Sourcefn to_sql_checked(
&self,
ty: &Type,
out: &mut BytesMut,
) -> Result<IsNull, Box<dyn Error + Sync + Send>>
fn to_sql_checked( &self, ty: &Type, out: &mut BytesMut, ) -> Result<IsNull, Box<dyn Error + Sync + Send>>
An adaptor method used internally by Rust-Postgres. Read more
Sourcefn encode_format(&self, _ty: &Type) -> Format
fn encode_format(&self, _ty: &Type) -> Format
Specify the encode format
impl StructuralPartialEq for SpecialSubject